Name:           nginx
Version:        1.27.5
Release:        1%{?dist}
Summary:        High-performance HTTP(S), HTTP/2, and HTTP/3 web server

License:        BSD
URL:            https://nginx.org/
Source0:        nginx-%{version}.tar.gz
Source1:        nginx.service
Source2:        nginx.logrotate

# 👇 Toggle OpenSSL version here (openssl-3.5.1 or openssl-3.2.1)
%global openssl_ver openssl-3.5.1

BuildRequires:  gcc, make, git, perl-devel, gd-devel, libxslt-devel, zlib-devel, pcre-devel, redhat-rpm-config, libmaxminddb-devel
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description
NGINX is a high-performance web server with support for HTTP/2, HTTP/3, TLS 1.3,
static content delivery, reverse proxying, and advanced configuration.

%prep
%setup -q

cp -a %{_sourcedir}/%{openssl_ver} ../
cp -a %{_sourcedir}/pcre-8.45 ../
cp -a %{_sourcedir}/zlib-cloudflare ../

# Patch zlib distclean bug
echo -e "distclean:\n\t@true" > ../zlib-cloudflare/Makefile

# Modules
cp -a %{_sourcedir}/ngx_brotli ../
cd ../ngx_brotli && git submodule update --init && cd -

cp -a %{_sourcedir}/headers-more-nginx-module ../
cp -a %{_sourcedir}/ngx_http_geoip2_module ../
cp -a %{_sourcedir}/redis2-nginx-module ../
cp -a %{_sourcedir}/ngx-fancyindex ../

%build
./configure \
  --prefix=%{_sysconfdir}/nginx \
  --sbin-path=%{_sbindir}/nginx \
  --conf-path=%{_sysconfdir}/nginx/nginx.conf \
  --pid-path=/run/nginx.pid \
  --lock-path=/run/nginx.lock \
  --error-log-path=%{_localstatedir}/log/nginx/error.log \
  --http-log-path=%{_localstatedir}/log/nginx/access.log \
  --modules-path=%{_libdir}/nginx/modules \
  --user=nginx \
  --group=nginx \
  --with-compat \
  --with-threads \
  --with-file-aio \
  --with-http_ssl_module \
  --with-http_v2_module \
  --with-http_v3_module \
  --with-http_realip_module \
  --with-http_gzip_static_module \
  --with-http_stub_status_module \
  --with-http_addition_module \
  --with-http_xslt_module=dynamic \
  --with-http_image_filter_module=dynamic \
  --with-http_sub_module \
  --with-http_dav_module \
  --with-http_flv_module \
  --with-http_mp4_module \
  --with-http_gunzip_module \
  --with-http_auth_request_module \
  --with-http_secure_link_module \
  --with-http_slice_module \
  --with-http_perl_module=dynamic \
  --with-stream \
  --with-stream_ssl_module \
  --with-stream_realip_module \
  --with-stream_ssl_preread_module \
  --with-zlib=../zlib-cloudflare \
  --with-openssl=../%{openssl_ver} \
  --with-openssl-opt="no-shared no-threads no-tests --prefix=$PWD/../%{openssl_ver}/.openssl" \
  --with-pcre=../pcre-8.45 \
  --with-pcre-jit \
  --add-module=../ngx_brotli \
  --add-module=../ngx_http_geoip2_module \
  --add-module=../headers-more-nginx-module \
  --add-module=../redis2-nginx-module \
  --add-module=../ngx-fancyindex

make %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_sysconfdir}/nginx
mkdir -p %{buildroot}%{_localstatedir}/log/nginx

install -m 0755 objs/nginx %{buildroot}%{_sbindir}/nginx
install -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/nginx.service
install -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/nginx

cp -r conf/* %{buildroot}%{_sysconfdir}/nginx/

# Safe compatibility symlink
mkdir -p %{buildroot}/etc/nginx
if [ ! -e %{buildroot}/etc/nginx/nginx.conf ]; then
  ln -s %{_sysconfdir}/nginx/nginx.conf %{buildroot}/etc/nginx/nginx.conf
fi

# License and doc
mkdir -p %{buildroot}%{_licensedir}/nginx
cp -p LICENSE %{buildroot}%{_licensedir}/nginx/

mkdir -p %{buildroot}%{_docdir}/nginx
[ -f README ] && cp -p README %{buildroot}%{_docdir}/nginx/README || echo "Built from source" > %{buildroot}%{_docdir}/nginx/README

%post
%systemd_post nginx.service

%preun
%systemd_preun nginx.service

%postun
%systemd_postun_with_restart nginx.service

%files
%license %{_licensedir}/nginx/LICENSE
%doc %{_docdir}/nginx/*
%{_sbindir}/nginx
%{_unitdir}/nginx.service
%config(noreplace) %{_sysconfdir}/logrotate.d/nginx
%config(noreplace) %{_sysconfdir}/nginx/*
%dir %{_localstatedir}/log/nginx
%ghost /run/nginx.pid

%changelog
* Sat Jul 05 2025 HighProxies RPM <admin@highproxies.io> - 1.27.5-1
- Final stable NGINX RPM: OpenSSL 3.5.1 or 3.2.1, Brotli, GeoIP2, Redis2, FancyIndex
- Patched zlib distclean, added fallback README, improved doc/compatibility
- Production ready for Rocky 9+, systemd, and logrotate
